@@ -8,7 +8,7 @@
 #include "VCFPrinter.h"
 
 void VCFPrinter::print_header() {
-	fprintf(file, "%s", "##fileformat=VCFv4.2\n");
+	fprintf(file, "%s", "##fileformat=VCFv4.3\n");
 	fprintf(file, "%s", "##source=Sniffles\n");
 	string time = currentDateTime();
 	fprintf(file, "%s", "##fileDate=");
@@ -37,18 +37,28 @@ void VCFPrinter::print_header() {
 	fprintf(file, "%s", "##INFO=<ID=RE,Number=1,Type=Integer,Description=\"read support\">\n");
 	fprintf(file, "%s", "##INFO=<ID=IMPRECISE,Number=0,Type=Flag,Description=\"Imprecise structural variation\">\n");
 	fprintf(file, "%s", "##INFO=<ID=PRECISE,Number=0,Type=Flag,Description=\"Precise structural variation\">\n");
+	fprintf(file, "%s", "##INFO=<ID=UNRESOLVED,Number=0,Type=Flag,Description=\"An insertion that is longer than the read and thus we cannot predict the full size.\">\n");
 	fprintf(file, "%s", "##INFO=<ID=SVLEN,Number=1,Type=Integer,Description=\"Length of the SV\">\n");
+	fprintf(file, "%s", "##INFO=<ID=REF_strand,Number=2,Type=Integer,Description=\"Length of the SV\">\n");
 	fprintf(file, "%s", "##INFO=<ID=SVMETHOD,Number=1,Type=String,Description=\"Type of approach used to detect SV\">\n");
 	fprintf(file, "%s", "##INFO=<ID=SVTYPE,Number=1,Type=String,Description=\"Type of structural variant\">\n");
 	if (Parameter::Instance()->report_n_reads > 0 || Parameter::Instance()->report_n_reads == -1) {
-		fprintf(file, "%s", "##INFO=<ID=RNAMES,Number=1,Type=String,Description=\"Names of reads supporting SVs (comma seperated)\">\n");
+		fprintf(file, "%s", "##INFO=<ID=RNAMES,Number=1,Type=String,Description=\"Names of reads supporting SVs (comma separated)\">\n");
 	}
+	if (Parameter::Instance()->print_seq) {
+		fprintf(file, "%s", "##INFO=<ID=SEQ,Number=1,Type=String,Description=\"Extracted sequence from the best representative read.\">\n");
+	}
+
+	if (Parameter::Instance()->read_strand) {
+		fprintf(file, "%s", "##INFO=<ID=STRANDS2,Number=4,Type=Integer,Description=\"alt reads first + ,alt reads first -,alt reads second + ,alt reads second -.\">\n");
+		fprintf(file, "%s", "##INFO=<ID=REF_strand,Number=2,Type=Integer,Description=\"plus strand ref, minus strand ref.\">\n");
+	}
+
 	fprintf(file, "%s", "##INFO=<ID=STD_quant_start,Number=A,Type=Integer,Description=\"STD of the start breakpoints across the reads.\">\n");
 	fprintf(file, "%s", "##INFO=<ID=STD_quant_stop,Number=A,Type=Integer,Description=\"STD of the stop breakpoints across the reads.\">\n");
-	fprintf(file, "%s", "##INFO=<ID=Kurtosis_quant_start,Number=A,Type=Integer,Description=\"Kurtosis value of the start breakpoints accross the reads.\">\n");
-	fprintf(file, "%s", "##INFO=<ID=Kurtosis_quant_stop,Number=A,Type=Integer,Description=\"Kurtosis value of the stop breakpoints accross the reads.\">\n");
-	fprintf(file, "%s", "##INFO=<ID=SUPTYPE,Number=1,Type=String,Description=\"Type by which the variant is supported.(SR,ALN)\">\n");
-	fprintf(file, "%s", "##INFO=<ID=SUPTYPE,Number=1,Type=String,Description=\"Type by which the variant is supported.(SR,ALN)\">\n");
+	fprintf(file, "%s", "##INFO=<ID=Kurtosis_quant_start,Number=A,Type=Integer,Description=\"Kurtosis value of the start breakpoints across the reads.\">\n");
+	fprintf(file, "%s", "##INFO=<ID=Kurtosis_quant_stop,Number=A,Type=Integer,Description=\"Kurtosis value of the stop breakpoints across the reads.\">\n");
+	fprintf(file, "%s", "##INFO=<ID=SUPTYPE,Number=1,Type=String,Description=\"Type by which the variant is supported.(SR,ALN,NR)\">\n");
 	fprintf(file, "%s", "##INFO=<ID=STRANDS,Number=A,Type=String,Description=\"Strand orientation of the adjacency in BEDPE format (DEL:+-, DUP:-+, INV:++/--)\">\n");
 	fprintf(file, "%s", "##INFO=<ID=AF,Number=A,Type=Float,Description=\"Allele Frequency.\">\n");
 	fprintf(file, "%s", "##INFO=<ID=ZMW,Number=A,Type=Integer,Description=\"Number of ZMWs (Pacbio) supporting SV.\">\n");
@@ -89,9 +99,9 @@ void VCFPrinter::print_body(Breakpoint * &SV, RefVector ref) {
 			fprintf(file, "%i", id);
 			id++;
 
-			long end_coord=SV->get_coordinates().stop.most_support;
+			long end_coord = SV->get_coordinates().stop.most_support;
 			if (((SV->get_SVtype() & INS) && SV->get_length() == Parameter::Instance()->huge_ins) && SV->get_types().is_ALN) {
-				end_coord=std::max((SV->get_coordinates().stop.most_support - (long)SV->get_length()),(long) start);
+				end_coord = std::max((SV->get_coordinates().stop.most_support - (long) SV->get_length()), (long) start);
 			}
 
 			int end = IPrinter::calc_pos(end_coord, ref, chr);
@@ -123,11 +133,10 @@ void VCFPrinter::print_body(Breakpoint * &SV, RefVector ref) {
 
 			if (((SV->get_SVtype() & INS) && SV->get_length() == Parameter::Instance()->huge_ins) && SV->get_types().is_ALN) {
 				fprintf(file, "%s", "\t.\tUNRESOLVED\t");
-			}else{
+			} else {
 				fprintf(file, "%s", "\t.\tPASS\t");
 			}
 
-
 			if (std_quant.first < 10 && std_quant.second < 10) {
 				fprintf(file, "%s", "PRECISE");
 			} else {
@@ -144,7 +153,7 @@ void VCFPrinter::print_body(Breakpoint * &SV, RefVector ref) {
 				//if (SV->get_SVtype() & INS) {
 				//	fprintf(file, "%i", std::max((int) (end - SV->get_length()), start));
 				//} else {
-					fprintf(file, "%i", end);
+				fprintf(file, "%i", end);
 				//}
 			}
 			if (zmws != 0) {
@@ -175,15 +184,49 @@ void VCFPrinter::print_body(Breakpoint * &SV, RefVector ref) {
 			fprintf(file, "%s", SV->get_supporting_types().c_str());
 			fprintf(file, "%s", ";SVLEN=");
 
-			if (((SV->get_SVtype() & INS) && SV->get_length() == Parameter::Instance()->huge_ins) && SV->get_types().is_ALN) {//!
+			if (((SV->get_SVtype() & INS) && SV->get_length() == Parameter::Instance()->huge_ins) && SV->get_types().is_ALN) {				//!
 				fprintf(file, "%i", 999999999);
-			} else {
+			}else if (SV->get_SVtype() & TRA){
+				fprintf(file, "%i",0);
+			}else if (SV->get_SVtype() & DEL){
+				fprintf(file, "%i", SV->get_length()*-1);
+			}else {
 				fprintf(file, "%i", SV->get_length());
 			}
 			//	}
 			fprintf(file, "%s", ";STRANDS=");
 			fprintf(file, "%s", strands.c_str());
-			if (!SV->get_sequence().empty()) {
+			if (Parameter::Instance()->read_strand) {
+				fprintf(file, "%s", ";STRANDS2=");
+				std::map<std::string, read_str> support = SV->get_coordinates().support;
+				pair<int, int> tmp_start;
+				pair<int, int> tmp_stop;
+				tmp_start.first = 0;
+				tmp_start.second = 0;
+				tmp_stop.first = 0;
+				tmp_stop.second = 0;
+				for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
+					if ((*i).second.read_strand.first) {
+						tmp_start.first++;
+					} else {
+						tmp_start.second++;
+					}
+					if ((*i).second.read_strand.second) {
+						tmp_stop.first++;
+					} else {
+						tmp_stop.second++;
+					}
+				}
+				fprintf(file, "%i", tmp_start.first);
+				fprintf(file, "%s", ",");
+				fprintf(file, "%i", tmp_start.second);
+				fprintf(file, "%s", ",");
+				fprintf(file, "%i", tmp_stop.first);
+				fprintf(file, "%s", ",");
+				fprintf(file, "%i", tmp_stop.second);
+			}
+
+			if (Parameter::Instance()->print_seq && !SV->get_sequence().empty()) {
 				fprintf(file, "%s", ";SEQ=");
 				fprintf(file, "%s", SV->get_sequence().c_str());
 			}
@@ -204,6 +247,13 @@ void VCFPrinter::print_body_recall(Breakpoint * &SV, RefVector ref) {
 	if (Parameter::Instance()->phase) {
 		store_readnames(SV->get_read_ids(), id);
 	}
+
+	pair<double, double> kurtosis;
+	pair<double, double> std_quant;
+	double std_length = 0;
+	int zmws = 0;
+	bool ok_to_print = to_print(SV, std_quant, kurtosis, std_length, zmws);
+
 	std::string chr;
 	int start = IPrinter::calc_pos(SV->get_coordinates().start.most_support, ref, chr);
 	fprintf(file, "%s", chr.c_str());
